.. _glossary:

********
Glossary
********

.. glossary::

    additional menu
        Additional menu is a dynamic navigation that is generated from inner pages after lasts were visited. Configuration key "MAX_INNERLINK_HISTORY" set a max number inner pages in menu.
        
        .. seealso:: :ref:`Preferences`.

    api page
        Api page is a page available only by REST API.
        
        .. seealso:: :ref:`technical_configuration`.

    api & menu page
        Api & menu page is a combination of **api page** and **menu page**.
        
        .. seealso:: :ref:`technical_configuration`.

    inner page
        Inner page is a page available as a link inside page text. Such kind of pages are not part of main menu but after visited inner pages they are formed the **additional menu**.
        
        .. seealso:: :ref:`technical_configuration`.

    menu page
        Menu page is a page with link in the main menu.
        
        .. seealso:: :ref:`technical_configuration`.
